#!/usr/bin/perl
#
# (C) 2001-2003
#	Pozsar Balazs	<pozsy@uhulinux.hu>
#
# This file is originally part of the UHU-Linux distribution.
# Distributable under GPL v2.
#

# ----- Pragmatic modules -----------------------------------------------------
use strict;
use warnings;

# -----------------------------------------------------------------------------
package UHU::module;

use UHU::gtk2;
use UHU::common;

use Locale::gettext;
use Encode;
# ----- Exporter --------------------------------------------------------------
require Exporter;
our @ISA    = qw(Exporter);
our @EXPORT = qw(
droot lroot ddir ldir

start_module quit_module

load_module_ui
);

my $module;
my $domain;

sub import($$;$) {
	(undef, $module, $domain) = @_;

	$module = ($module or '/');
	$domain = ($domain or '/');

	debug "UHU::module imported."
	. ($module ? " module=[$module]" : '')
	. ($domain ? " domain=[$domain]" : '');

	my $textdomain = ($domain eq '/') ? $module : $domain;
	textdomain $textdomain;
	bind_textdomain_codeset $textdomain,'utf8';
	UHU::module->export_to_level(1);
}
# ----- I18N ------------------------------------------------------------------
sub _ {
	my ($string,@rest) = @_;
	my $tr = gettext($string);
	Encode::_utf8_on($tr);
	sprintf($tr,@rest);
}
# ----- Subroutines -----------------------------------------------------------
my $main_window;

sub droot() {
	$ENV{MODULE_ROOT} . '/' . $ENV{MODULE_DDIR_ROOT} . '/' . $domain . '/';
}

sub lroot() {
	$ENV{MODULE_ROOT} . '/' . $ENV{MODULE_LDIR_ROOT} . '/' . $domain . '/';
}

sub ddir() {
	droot . '/' . $module . '/';
}

sub ldir() {
	lroot . '/' . $module . '/';
}

my $notebook;

sub start_module() {
	debug "start_module [$domain][$module]";
	kill 12, $ENV{JUHHU_PID} if $ENV{JUHHU_PID};
	$notebook->set_current_page(1);
	main Gtk2;
}

sub quit_module() {
	debug "quit_module [$domain][$module]";
	$notebook->set_current_page(0) unless $ENV{JUHHU_PID};
	$ENV{JUHHU_PID} ? kill 10, $ENV{JUHHU_PID} : exit 0;
}

sub load_module_ui(;$$) {
	my ($msg, $screensize) = @_;

	my $ui = droot . '/' . $module . '/' . $module . '.glade2';

	my $parent;
	if ($ENV{JUHHU_XID}) {
		$parent = plug $ENV{JUHHU_XID};
	} else {
		$parent = new Gtk2::Window 'toplevel';
#		$parent->set_policy(0, 1, 1);    # egyszer autoshrinkelunk
#		$parent->set_policy(0, 1, 0);    # de tobbet nem
		if ($screensize) {
			$parent->set_default_size(($screensize eq 'fullscreen') ? Xres : split /x/, $screensize);
		}
	}

	$parent->signal_connect('remove', \&quit_module);
	$parent->show;

	$notebook = new Gtk2::Notebook;
	$notebook->set_show_tabs(0);
	$notebook->set_show_border(0);
	$notebook->show;
	$parent->add($notebook);

	my $label = new Gtk2::Label($msg or _("Please wait..."));
	$label->show;
	$notebook->append_page($label, new Gtk2::Label);

	gtk_iterate;

	my $vbox = new Gtk2::VBox;
	$vbox->show;
	$notebook->append_page($vbox, new Gtk2::Label);

	my $g = load_ui_into_container($ui, 'main', $vbox);
	w($g, 'window')->hide;
	w($g, 'window')->destroy;

#	set_cursor w($g, 'main');

	$g;
}

# ----- Initialization --------------------------------------------------------
default_env 'MODULE_ROOT',      $ENV{UHU_ROOT} . '/';
default_env 'MODULE_DDIR_ROOT', '/usr/share';
default_env 'MODULE_LDIR_ROOT', '/usr/lib';

# ----- Beatiful perl :) ------------------------------------------------------
"Indul a gorog a ludnI";
